namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Hoversel::horizontal_get() const
{
   Eina_Bool __return_value =  ::elm_obj_hoversel_horizontal_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hoversel::horizontal_set( ::efl::eolian::in_traits<bool>::type horizontal) const
{
    ::elm_obj_hoversel_horizontal_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(horizontal));
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Hoversel::hover_parent_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_hoversel_hover_parent_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hoversel::hover_parent_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type parent) const
{
    ::elm_obj_hoversel_hover_parent_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(parent));
}
inline ::efl::eolian::return_traits<bool>::type Hoversel::expanded_get() const
{
   Eina_Bool __return_value =  ::elm_obj_hoversel_expanded_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type Hoversel::items_get() const
{
   const Eina_List * __return_value =  ::elm_obj_hoversel_items_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Hoversel::auto_update_get() const
{
   Eina_Bool __return_value =  ::elm_obj_hoversel_auto_update_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hoversel::auto_update_set( ::efl::eolian::in_traits<bool>::type auto_update) const
{
    ::elm_obj_hoversel_auto_update_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(auto_update));
}
inline ::efl::eolian::return_traits<void>::type Hoversel::hover_begin() const
{
    ::elm_obj_hoversel_hover_begin(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Hoversel::clear() const
{
    ::elm_obj_hoversel_clear(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Hoversel::hover_end() const
{
    ::elm_obj_hoversel_hover_end(this->_eo_ptr());
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Hoversel::item_add( ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type icon_file,  ::efl::eolian::in_traits<Elm_Icon_Type>::type icon_type,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void const*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_hoversel_item_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(label)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(icon_file)
      ,  ::efl::eolian::convert_to_c<Elm_Icon_Type,  ::efl::eolian::in_traits<Elm_Icon_Type>::type>(icon_type)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<const void *,  ::efl::eolian::in_traits<void const*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Hoversel::horizontal_get() const
{
   Eina_Bool __return_value =  ::elm_obj_hoversel_horizontal_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hoversel::horizontal_set( ::efl::eolian::in_traits<bool>::type horizontal) const
{
    ::elm_obj_hoversel_horizontal_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(horizontal));
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Hoversel::hover_parent_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_hoversel_hover_parent_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hoversel::hover_parent_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type parent) const
{
    ::elm_obj_hoversel_hover_parent_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(parent));
}
inline ::efl::eolian::return_traits<bool>::type Hoversel::expanded_get() const
{
   Eina_Bool __return_value =  ::elm_obj_hoversel_expanded_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type Hoversel::items_get() const
{
   const Eina_List * __return_value =  ::elm_obj_hoversel_items_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Hoversel::auto_update_get() const
{
   Eina_Bool __return_value =  ::elm_obj_hoversel_auto_update_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hoversel::auto_update_set( ::efl::eolian::in_traits<bool>::type auto_update) const
{
    ::elm_obj_hoversel_auto_update_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(auto_update));
}
inline ::efl::eolian::return_traits<void>::type Hoversel::hover_begin() const
{
    ::elm_obj_hoversel_hover_begin(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Hoversel::clear() const
{
    ::elm_obj_hoversel_clear(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Hoversel::hover_end() const
{
    ::elm_obj_hoversel_hover_end(this->_eo_ptr());
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Hoversel::item_add( ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type icon_file,  ::efl::eolian::in_traits<Elm_Icon_Type>::type icon_type,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void const*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_hoversel_item_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(label)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::optional< ::efl::eina::string_view>>::type>(icon_file)
      ,  ::efl::eolian::convert_to_c<Elm_Icon_Type,  ::efl::eolian::in_traits<Elm_Icon_Type>::type>(icon_type)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<const void *,  ::efl::eolian::in_traits<void const*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline elm::Hoversel::operator ::elm::Hoversel() const { return *static_cast< ::elm::Hoversel const*>(static_cast<void const*>(this)); }
inline elm::Hoversel::operator ::elm::Hoversel&() { return *static_cast< ::elm::Hoversel*>(static_cast<void*>(this)); }
inline elm::Hoversel::operator ::elm::Hoversel const&() const { return *static_cast< ::elm::Hoversel const*>(static_cast<void const*>(this)); }
} }

